==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebMaskInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMaskInputBaseDescriptionMetadata } from "./WebMaskInputBaseDescriptionMetadata";
import { WebMaskInputDescription } from "./WebMaskInputDescription";
/**
 * @hidden
 */
export let WebMaskInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMaskInputDescriptionMetadata extends Base {
        static b(a) {
            if (WebMaskInputDescriptionMetadata.a == null) {
                WebMaskInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMaskInputDescriptionMetadata.c(WebMaskInputDescriptionMetadata.a);
            }
            if (a.j(WebMaskInputDescriptionMetadata.a)) {
                return;
            }
            a.y(WebMaskInputDescriptionMetadata.a);
        }
        static c(a) {
            WebMaskInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MaskInput");
            a.item("__tagNameWC", "String:igc-mask-input");
            a.item("ValueMode", "ExportedType:string:MaskInputValueMode");
            a.item("ValueMode@names", "Raw;WithFormatting");
            a.item("Value", "String");
            a.item("Mask", "String");
        }
        static d(a) {
            WebMaskInputDescriptionMetadata.b(a);
            a.aa("WebMaskInput", () => new WebMaskInputDescription());
            a.z("WebMaskInput", WebMaskInputDescriptionMetadata.a);
        }
    }
    WebMaskInputDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMaskInputDescriptionMetadata, 'WebMaskInputDescriptionMetadata');
    WebMaskInputDescriptionMetadata.a = null;
    return WebMaskInputDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebMaskInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMaskInputBaseDescriptionMetadata } from "./WebMaskInputBaseDescriptionMetadata";
import { WebMaskInputDescription } from "./WebMaskInputDescription";
/**
 * @hidden
 */
export let WebMaskInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMaskInputDescriptionMetadata extends Base {
        static b(a) {
            if (WebMaskInputDescriptionMetadata.a == null) {
                WebMaskInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMaskInputDescriptionMetadata.c(WebMaskInputDescriptionMetadata.a);
            }
            if (a.k(WebMaskInputDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebMaskInputDescriptionMetadata.a);
        }
        static c(a) {
            WebMaskInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MaskInput");
            a.item("__tagNameWC", "String:igc-mask-input");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("ValueMode", "ExportedType:string:MaskInputValueMode");
            a.item("ValueMode@names", "Raw;WithFormatting");
            a.item("Value", "String");
            a.item("Mask", "String");
        }
        static d(a) {
            WebMaskInputDescriptionMetadata.b(a);
            a.ac("WebMaskInput", () => new WebMaskInputDescription());
            a.ab("WebMaskInput", WebMaskInputDescriptionMetadata.a);
        }
    }
    WebMaskInputDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMaskInputDescriptionMetadata, 'WebMaskInputDescriptionMetadata');
    WebMaskInputDescriptionMetadata.a = null;
    return WebMaskInputDescriptionMetadata;
})();
